@@ -4,11 +4,11 @@ require 5.003000;
 
 use strict;
 use warnings;
-use vars qw($VERSION @ISA @EXPORT @EXPORT_OK);
-use Fcntl;
+use vars qw($VERSION @ISA @EXPORT_OK);
+use Fcntl qw(O_RDONLY);
 use integer;
 
-$VERSION = '0.24';
+$VERSION = '0.25';
 
 require Exporter;
 require DynaLoader;
@@ -204,7 +204,7 @@ In programs:
 =head1 ABSTRACT
 
 Digest::SHA3 is a complete implementation of the NIST SHA-3
-cryptographic hash function, as specified in Draft FIPS 202 (SHA-3
+cryptographic hash function, as specified in FIPS 202 (SHA-3
 Standard: Permutation-Based Hash and Extendable-Output Functions).
 
 The module gives Perl programmers a convenient way to calculate
@@ -327,7 +327,7 @@ it's unlikely that future versions of this module will support a
 32-bit implementation.  Older platforms using 32-bit-only compilers
 should continue to favor 32-bit hash implementations such as SHA-1,
 SHA-224, or SHA-256.  The desire to use the SHA-3 hash standard,
-dating from 2012, should reasonably require that one's compiler
+dating from 2015, should reasonably require that one's compiler
 adhere to programming language standards dating from at least 1999.
 
 I<Functional style>
@@ -567,9 +567,9 @@ This method is B<applicable only to SHAKE128 and SHAKE256 objects>.
 
 L<Digest>, L<Digest::SHA>, L<Digest::Keccak>
 
-The Draft FIPS 202 SHA-3 Standard can be found at:
+The FIPS 202 SHA-3 Standard can be found at:
 
-L<http://csrc.nist.gov/publications/drafts/fips-202/fips_202_draft.pdf>
+L<http://nvlpubs.nist.gov/nistpubs/FIPS/NIST.FIPS.202.pdf>
 
 The Keccak/SHA-3 specifications can be found at:
 
@@ -598,7 +598,7 @@ and lasting happiness."
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2012-2015 Mark Shelor
+Copyright (C) 2012-2016 Mark Shelor
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
