@@ -3,10 +3,10 @@
  *
  * Ref: http://keccak.noekeon.org/specs_summary.html
  *
- * Copyright (C) 2012-2015 Mark Shelor, All Rights Reserved
+ * Copyright (C) 2012-2016 Mark Shelor, All Rights Reserved
  *
- * Version: 0.24
- * Sat Jan 10 00:45:34 MST 2015
+ * Version: 0.25
+ * Wed Jul 27 20:04:40 MST 2016
  *
  */
 
@@ -272,10 +272,10 @@ static ULNG shabits(UCHR *bitstr, ULNG bitcnt, SHA3 *s)
 
 	for (i = 0UL; i < bitcnt; i++) {
 		if (BITSET(bitstr, i))
-			SETBIT(s->block, s->blockcnt), s->blockcnt++;
+			SETBIT(s->block, s->blockcnt);
 		else
-			CLRBIT(s->block, s->blockcnt), s->blockcnt++;
-		if (s->blockcnt == s->blocksize)
+			CLRBIT(s->block, s->blockcnt);
+		if (++s->blockcnt == s->blocksize)
 			sha3(s, s->block), s->blockcnt = 0;
 	}
 	return(bitcnt);
